@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,25 +11,21 @@ import select
 from unittest import TestResult
 
 
-from DebugProtocol import ResponseUTTestFailed, ResponseUTTestErrored, \
-    ResponseUTStartTest, ResponseUTStopTest, ResponseUTTestSkipped, \
-    ResponseUTTestFailedExpected, ResponseUTTestSucceededUnexpected
-
-
 class DCTestResult(TestResult):
     """
     A TestResult derivative to work with eric6's debug client.
     
     For more details see unittest.py of the standard python distribution.
     """
-    def __init__(self, parent):
+    def __init__(self, dbgClient):
         """
         Constructor
         
-        @param parent The parent widget.
+        @param dbgClient reference to the debug client
+        @type DebugClientBase
         """
         TestResult.__init__(self)
-        self.parent = parent
+        self.__dbgClient = dbgClient
         
     def addFailure(self, test, err):
         """
@@ -40,10 +36,11 @@ class DCTestResult(TestResult):
         """
         TestResult.addFailure(self, test, err)
         tracebackLines = self._exc_info_to_string(err, test)
-        self.parent.write(
-            '%s%s\n' % (
-                ResponseUTTestFailed,
-                unicode((unicode(test), tracebackLines, test.id()))))
+        self.__dbgClient.sendJsonCommand("ResponseUTTestFailed", {
+            "testname": str(test),
+            "traceback": tracebackLines,
+            "id": test.id(),
+        })
         
     def addError(self, test, err):
         """
@@ -54,10 +51,11 @@ class DCTestResult(TestResult):
         """
         TestResult.addError(self, test, err)
         tracebackLines = self._exc_info_to_string(err, test)
-        self.parent.write(
-            '%s%s\n' % (
-                ResponseUTTestErrored,
-                unicode((unicode(test), tracebackLines, test.id()))))
+        self.__dbgClient.sendJsonCommand("ResponseUTTestErrored", {
+            "testname": str(test),
+            "traceback": tracebackLines,
+            "id": test.id(),
+        })
         
     def addSkip(self, test, reason):
         """
@@ -67,10 +65,11 @@ class DCTestResult(TestResult):
         @param reason reason for skipping the test (string)
         """
         TestResult.addSkip(self, test, reason)
-        self.parent.write(
-            '%s%s\n' % (
-                ResponseUTTestSkipped,
-                str((str(test), reason, test.id()))))
+        self.__dbgClient.sendJsonCommand("ResponseUTTestSkipped", {
+            "testname": str(test),
+            "reason": reason,
+            "id": test.id(),
+        })
         
     def addExpectedFailure(self, test, err):
         """
@@ -81,10 +80,11 @@ class DCTestResult(TestResult):
         """
         TestResult.addExpectedFailure(self, test, err)
         tracebackLines = self._exc_info_to_string(err, test)
-        self.parent.write(
-            '%s%s\n' % (
-                ResponseUTTestFailedExpected,
-                str((str(test), tracebackLines, test.id()))))
+        self.__dbgClient.sendJsonCommand("ResponseUTTestFailedExpected", {
+            "testname": str(test),
+            "traceback": tracebackLines,
+            "id": test.id(),
+        })
         
     def addUnexpectedSuccess(self, test):
         """
@@ -93,10 +93,10 @@ class DCTestResult(TestResult):
         @param test reference to the test object
         """
         TestResult.addUnexpectedSuccess(self, test)
-        self.parent.write(
-            '%s%s\n' % (
-                ResponseUTTestSucceededUnexpected,
-                str((str(test), test.id()))))
+        self.__dbgClient.sendJsonCommand("ResponseUTTestSucceededUnexpected", {
+            "testname": str(test),
+            "id": test.id(),
+        })
         
     def startTest(self, test):
         """
@@ -105,10 +105,10 @@ class DCTestResult(TestResult):
         @param test Reference to the test object
         """
         TestResult.startTest(self, test)
-        self.parent.write(
-            '%s%s\n' % (
-                ResponseUTStartTest,
-                unicode((unicode(test), test.shortDescription()))))
+        self.__dbgClient.sendJsonCommand("ResponseUTStartTest", {
+            "testname": str(test),
+            "description": test.shortDescription(),
+        })
 
     def stopTest(self, test):
         """
@@ -117,15 +117,14 @@ class DCTestResult(TestResult):
         @param test Reference to the test object
         """
         TestResult.stopTest(self, test)
-        self.parent.write('%s\n' % ResponseUTStopTest)
+        self.__dbgClient.sendJsonCommand("ResponseUTStopTest", {})
         
         # ensure that pending input is processed
-        rrdy, wrdy, xrdy = select.select([self.parent.readstream], [], [],
-                                         0.01)
+        rrdy, wrdy, xrdy = select.select(
+            [self.__dbgClient.readstream], [], [], 0.01)
 
-        if self.parent.readstream in rrdy:
-            self.parent.readReady(self.parent.readstream.fileno())
+        if self.__dbgClient.readstream in rrdy:
+            self.__dbgClient.readReady(self.__dbgClient.readstream)
 
 #
-# eflag: FileType = Python2
-# eflag: noqa = M601, M702
+# eflag: noqa = M702
