@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -508,8 +508,8 @@ class DebugServer(QTcpServer):
                 elif self.__autoClearShell:
                     self.__autoClearShell = False
                     self.remoteBanner()
-                self.remoteClientVariables(0, [], 0)
-                self.remoteClientVariables(1, [], 0)
+##                self.remoteClientVariables(0, [], 0)
+##                self.remoteClientVariables(1, [], 0)
             else:
                 if clType and self.lastClientType:
                     self.__setClientType(self.lastClientType)
