@@ -617,7 +617,7 @@ class E5SideBar(QWidget):
         self.__maxSize = max(stream.readUInt16(), maxSize)
         count = stream.readUInt16()
         self.splitterSizes = []
-        for i in range(count):
+        for _ in range(count):
             self.splitterSizes.append(stream.readUInt16())
         
         self.__autoHide = stream.readBool()
