@@ -14,7 +14,8 @@ import time
 from E5Gui.E5Application import e5App
 
 from .XMLStreamWriterBase import XMLStreamWriterBase
-from .Config import projectFileFormatVersion, projectFileFormatVersionAlt
+from .Config import projectFileFormatVersion, projectFileFormatVersionProto, \
+    projectFileFormatVersionAlt
 
 import Preferences
 import Utilities
@@ -42,8 +43,10 @@ class ProjectWriter(XMLStreamWriterBase):
         """
         XMLStreamWriterBase.writeXML(self)
         
-        if self.pdata["PROTOCOLS"]:
+        if not e5App().getObject("Project").hasDefaultMakeParameters():
             fileFormatVersion = projectFileFormatVersion
+        elif self.pdata["PROTOCOLS"]:
+            fileFormatVersion = projectFileFormatVersionProto
         else:
             fileFormatVersion = projectFileFormatVersionAlt
         
@@ -214,6 +217,12 @@ class ProjectWriter(XMLStreamWriterBase):
                 self.writeAttribute("lexer", lexer)
             self.writeEndElement()
         
+        # do the 'make' parameters
+        if not e5App().getObject("Project").hasDefaultMakeParameters():
+            self.writeStartElement("Make")
+            self.writeBasics("MakeParameters", self.pdata["MAKEPARAMS"])
+            self.writeEndElement()
+        
         # do the extra project data stuff
         if len(self.pdata["PROJECTTYPESPECIFICDATA"]):
             self.writeStartElement("ProjectTypeSpecific")
