@@ -107,11 +107,13 @@ class UserAgentMenu(QMenu):
             else:
                 HelpWebPage().setUserAgent(userAgent)
     
-    def __changeUserAgent(self):
+    def __changeUserAgent(self, act):
         """
         Private slot to change the user agent.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         if self.__url:
             self.__manager.setUserAgentForUrl(self.__url, act.data())
         else:
@@ -157,7 +159,7 @@ class UserAgentMenu(QMenu):
                 act.setToolTip(userAgent)
                 act.setCheckable(True)
                 act.setChecked(userAgent == currentUserAgentString)
-                act.triggered.connect(self.__changeUserAgent)
+                act.triggered.connect(lambda: self.__changeUserAgent(act))
                 if menuStack:
                     menuStack[-1].addAction(act)
                 else:
