@@ -9,7 +9,7 @@ Module implementing an 'About Eric' dialog.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import QCoreApplication
+from PyQt5.QtCore import Qt, QCoreApplication
 from PyQt5.QtWidgets import QDialog
 
 from .Ui_AboutDialog import Ui_AboutDialog
@@ -748,6 +748,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         """
         super(AboutDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.ericLabel.setText(titleText)
         self.ericPixmap.setPixmap(
