@@ -23,9 +23,10 @@ except ImportError:
 
 from .Ui_PipSearchDialog import Ui_PipSearchDialog
 
-from . import DefaultIndexUrl
+from . import DefaultIndexUrlXml
 
 
+# TODO: add support for --user; additional button
 class PipSearchDialog(QDialog, Ui_PipSearchDialog):
     """
     Class implementing a dialog to search PyPI.
@@ -63,9 +64,11 @@ class PipSearchDialog(QDialog, Ui_PipSearchDialog):
         self.__showDetailsButton.setEnabled(False)
         
         self.__pip = pip
-        self.__client = E5XmlRpcClient(
-            plugin.getPreferences("PipSearchIndex") or DefaultIndexUrl,
-            self)
+        if plugin.getPreferences("PipSearchIndex"):
+            indexUrl = plugin.getPreferences("PipSearchIndex") + "/pypi"
+        else:
+            indexUrl = DefaultIndexUrlXml
+        self.__client = E5XmlRpcClient(indexUrl, self)
         
         self.__default = self.tr("<Default>")
         pipExecutables = sorted(plugin.getPreferences("PipExecutables"))
@@ -77,6 +80,8 @@ class PipSearchDialog(QDialog, Ui_PipSearchDialog):
         self.__canceled = False
         self.__detailsData = {}
         self.__query = []
+        
+        self.__packageDetailsDialog = None
     
     def closeEvent(self, e):
         """
@@ -85,6 +90,10 @@ class PipSearchDialog(QDialog, Ui_PipSearchDialog):
         @param e close event (QCloseEvent)
         """
         QApplication.restoreOverrideCursor()
+        
+        if self.__packageDetailsDialog is not None:
+            self.__packageDetailsDialog.close()
+        
         e.accept()
     
     @pyqtSlot(str)
@@ -312,6 +321,7 @@ class PipSearchDialog(QDialog, Ui_PipSearchDialog):
         
         return score
     
+    # TODO: add support for --user
     def __install(self):
         """
         Private slot to install the selected packages.
@@ -398,11 +408,17 @@ class PipSearchDialog(QDialog, Ui_PipSearchDialog):
         @param data result data (tuple) with downloads information in the first
             element
         """
+        from .PipPackageDetailsDialog import PipPackageDetailsDialog
+        
         self.__finish()
         self.__showDetailsButton.setEnabled(True)
-        from .PipPackageDetailsDialog import PipPackageDetailsDialog
-        dlg = PipPackageDetailsDialog(self.__detailsData, data[0], self)
-        dlg.exec_()
+        
+        if self.__packageDetailsDialog is not None:
+            self.__packageDetailsDialog.close()
+        
+        self.__packageDetailsDialog = \
+            PipPackageDetailsDialog(self.__detailsData, data[0], self)
+        self.__packageDetailsDialog.show()
     
     def __detailsError(self, errorCode, errorString):
         """
