@@ -319,7 +319,7 @@ class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
         filterTop = self.categoryCombo.currentText() == self.tr("Revision")
         if filterTop and searchRxText.startswith("^"):
             searchRx = QRegExp(
-                "^\s*{0}".format(searchRxText[1:]), Qt.CaseInsensitive)
+                r"^\s*{0}".format(searchRxText[1:]), Qt.CaseInsensitive)
         else:
             searchRx = QRegExp(searchRxText, Qt.CaseInsensitive)
         for topIndex in range(self.signaturesList.topLevelItemCount()):
