@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,7 +11,7 @@ from __future__ import unicode_literals
 
 import os
 
-from PyQt5.QtCore import QFileInfo, QRegExp, Qt, pyqtSlot, qVersion
+from PyQt5.QtCore import QFileInfo, QRegExp, Qt, pyqtSlot
 from PyQt5.QtGui import QClipboard, QTextCursor
 from PyQt5.QtWidgets import QWidget, QDialog, QApplication, QDialogButtonBox, \
     QVBoxLayout, QTableWidgetItem
@@ -25,6 +25,7 @@ import UI.PixmapCache
 
 import Utilities
 import Preferences
+from Globals import qVersionTuple
 
 
 class QRegExpWizardWidget(QWidget, Ui_QRegExpWizardWidget):
@@ -81,7 +82,7 @@ class QRegExpWizardWidget(QWidget, Ui_QRegExpWizardWidget):
         self.syntaxCombo.addItem("Unix Wildcard", QRegExp.WildcardUnix)
         self.syntaxCombo.addItem("Fixed String", QRegExp.FixedString)
         self.syntaxCombo.addItem("W3C XML Schema 1.1", QRegExp.W3CXmlSchema11)
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             self.syntaxCombo.setCurrentIndex(1)
         
         self.saveButton = self.buttonBox.addButton(
@@ -646,8 +647,8 @@ class QRegExpWizardWidget(QWidget, Ui_QRegExpWizardWidget):
                 istring, reVar, os.linesep)
         syntax = self.syntaxCombo.itemData(self.syntaxCombo.currentIndex())
         needPatternSyntax = True
-        if qVersion() < "5.0.0" and syntax == QRegExp.RegExp or \
-           qVersion() >= "5.0.0" and syntax == QRegExp.RegExp2:
+        if qVersionTuple() < (5, 0, 0) and syntax == QRegExp.RegExp or \
+           qVersionTuple() >= (5, 0, 0) and syntax == QRegExp.RegExp2:
             # default value selected
             needPatternSyntax = False
         if needPatternSyntax:
