@@ -49,6 +49,10 @@ class EditorAutocompletionPage(ConfigurationPageBase,
             Preferences.getEditor("AutoCompletionCacheTime"))
         self.acWatchdogDoubleSpinBox.setValue(
             Preferences.getEditor("AutoCompletionWatchdogTime") / 1000.0)
+        self.acLinesSlider.setValue(
+            Preferences.getEditor("AutoCompletionMaxLines"))
+        self.acCharSlider.setValue(
+            Preferences.getEditor("AutoCompletionMaxChars"))
         
     def save(self):
         """
@@ -85,6 +89,12 @@ class EditorAutocompletionPage(ConfigurationPageBase,
         Preferences.setEditor(
             "AutoCompletionWatchdogTime",
             self.acWatchdogDoubleSpinBox.value() * 1000)
+        Preferences.setEditor(
+            "AutoCompletionMaxLines",
+            self.acLinesSlider.value())
+        Preferences.setEditor(
+            "AutoCompletionMaxChars",
+            self.acCharSlider.value())
     
 
 def create(dlg):
