@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,7 @@ Module implementing the Editor Highlighting Styles configuration page.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSlot, Qt, QFileInfo, QFile, QIODevice, qVersion
+from PyQt5.QtCore import pyqtSlot, Qt, QFileInfo, QFile, QIODevice
 from PyQt5.QtGui import QPalette, QFont
 from PyQt5.QtWidgets import QColorDialog, QFontDialog, QInputDialog, QMenu
 
@@ -19,6 +19,7 @@ from .Ui_EditorHighlightingStylesPage import Ui_EditorHighlightingStylesPage
 from E5Gui import E5MessageBox, E5FileDialog
 
 import Preferences
+from Globals import qVersionTuple
 
 try:
     MonospacedFontsOption = QFontDialog.MonospacedFonts
@@ -47,7 +48,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         self.setupUi(self)
         self.setObjectName("EditorHighlightingStylesPage")
         
-        if qVersion() < "5.0.0":
+        if qVersionTuple() < (5, 0, 0):
             self.monospacedButton.setChecked(False)
             self.monospacedButton.hide()
         
@@ -478,10 +479,13 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         @param lexers dictionary of lexer objects for which to import the
             styles
         """
+        from eric6config import getConfig
+        stylesDir = getConfig("ericStylesDir")
+        
         fn = E5FileDialog.getOpenFileName(
             self,
             self.tr("Import Highlighting Styles"),
-            "",
+            stylesDir,
             self.tr("Highlighting styles file (*.e4h)"))
         
         if not fn:
