@@ -91,8 +91,12 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
             Preferences.getWebBrowser("PluginsEnabled"))
         self.doNotTrackCheckBox.setChecked(
             Preferences.getWebBrowser("DoNotTrack"))
-        self.sendRefererCheckBox.setChecked(
-            Preferences.getWebBrowser("SendReferer"))
+        self.refererSendComboBox.setCurrentIndex(
+            Preferences.getWebBrowser("RefererSendReferer"))
+        self.refererDefaultPolicyCcomboBox.setCurrentIndex(
+            Preferences.getWebBrowser("RefererDefaultPolicy"))
+        self.refererTrimmingPolicyComboBox.setCurrentIndex(
+            Preferences.getWebBrowser("RefererTrimmingPolicy"))
         
         self.diskCacheCheckBox.setChecked(
             Preferences.getWebBrowser("DiskCacheEnabled"))
@@ -260,8 +264,14 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
             "DoNotTrack",
             self.doNotTrackCheckBox.isChecked())
         Preferences.setWebBrowser(
-            "SendReferer",
-            self.sendRefererCheckBox.isChecked())
+            "RefererSendReferer",
+            self.refererSendComboBox.currentIndex())
+        Preferences.setWebBrowser(
+            "RefererDefaultPolicy",
+            self.refererDefaultPolicyCcomboBox.currentIndex())
+        Preferences.setWebBrowser(
+            "RefererTrimmingPolicy",
+            self.refererTrimmingPolicyComboBox.currentIndex())
         
         Preferences.setWebBrowser(
             "DiskCacheEnabled",
