@@ -107,7 +107,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         self.menu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             act = self.menu.addAction(
                 self.tr('Generate translation'), self.__generateSelected)
             self.tsMenuActions.append(act)
@@ -234,7 +234,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             act = self.backMenu.addAction(
                 self.tr('Generate all translations'),
                 self.__generateAll)
@@ -295,7 +295,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             act = self.multiMenu.addAction(
                 self.tr('Generate translations'),
                 self.__generateSelected)
@@ -379,7 +379,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             act = self.dirMenu.addAction(
                 self.tr('Generate all translations'),
                 self.__generateAll)
@@ -497,7 +497,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         """
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             tsFiles = 0
             qmFiles = 0
             itmList = self.getSelectedItems()
@@ -539,7 +539,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         """
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             tsFiles = 0
             qmFiles = 0
             itmList = self.getSelectedItems()
@@ -579,7 +579,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         """
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocDirMenuActions:
                     act.setEnabled(False)
@@ -599,7 +599,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         """
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocBackMenuActions:
                     act.setEnabled(False)
@@ -830,27 +830,25 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             
         return True
     
-    def __readStdoutLupdate(self):
+    def __readStdoutLupdate(self, proc):
         """
         Private slot to handle the readyReadStandardOutput signal of the
         pylupdate process.
-        """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStdout(proc, '{0}: '.format(self.pylupdate))
-        else:
-            return
         
-    def __readStdoutLrelease(self):
+        @param proc reference to the process
+        @type QProcess
+        """
+        self.__readStdout(proc, '{0}: '.format(self.pylupdate))
+        
+    def __readStdoutLrelease(self, proc):
         """
         Private slot to handle the readyReadStandardOutput signal of the
         lrelease process.
+        
+        @param proc reference to the process
+        @type QProcess
         """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStdout(proc, 'lrelease: ')
-        else:
-            return
+        self.__readStdout(proc, 'lrelease: ')
         
     def __readStdout(self, proc, ps):
         """
@@ -868,27 +866,25 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             s += output
             self.appendStdout.emit(s)
         
-    def __readStderrLupdate(self):
+    def __readStderrLupdate(self, proc):
         """
         Private slot to handle the readyReadStandardError signal of the
-        pylupdate4/pylupdate5/pyside-lupdate process.
-        """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStderr(proc, '{0}: '.format(self.pylupdate))
-        else:
-            return
+        pylupdate4/pylupdate5/pyside-lupdate/pyside2-lupdate process.
         
-    def __readStderrLrelease(self):
+        @param proc reference to the process
+        @type QProcess
+        """
+        self.__readStderr(proc, '{0}: '.format(self.pylupdate))
+        
+    def __readStderrLrelease(self, proc):
         """
         Private slot to handle the readyReadStandardError signal of the
         lrelease process.
+        
+        @param proc reference to the process
+        @type QProcess
         """
-        proc = self.sender()
-        if proc is not None:
-            self.__readStderr(proc, 'lrelease: ')
-        else:
-            return
+        self.__readStderr(proc, 'lrelease: ')
         
     def __readStderr(self, proc, ps):
         """
@@ -917,12 +913,16 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         if self.hooks["extractMessages"] is not None:
             self.hooks["extractMessages"]()
         
-    def __generateTSFileDone(self, exitCode, exitStatus):
+    def __generateTSFileDone(self, exitCode, exitStatus, proc):
         """
         Private slot to handle the finished signal of the pylupdate process.
         
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
+        @param proc reference to the process
+        @type QProcess
         """
         if exitStatus == QProcess.NormalExit and exitCode == 0:
             ui = e5App().getObject("UserInterface")
@@ -952,7 +952,6 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     "The generation of the translation files (*.ts) has"
                     " failed.{0}").format(info))
         
-        proc = self.sender()
         for index in range(len(self.__pylupdateProcesses)):
             if proc == self.__pylupdateProcesses[index][0]:
                 try:
@@ -1028,7 +1027,11 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             else:
                 self.pylupdate = Utilities.generatePyQtToolPath('pylupdate5')
         elif self.project.getProjectType() in ["PySide", "PySideC"]:
-            self.pylupdate = Utilities.generatePySideToolPath('pyside-lupdate')
+            self.pylupdate = Utilities.generatePySideToolPath(
+                'pyside-lupdate', "1")
+        elif self.project.getProjectType() in ["PySide2", "PySide2C"]:
+            self.pylupdate = Utilities.generatePySideToolPath(
+                'pyside2-lupdate', "2")
         else:
             return
 
@@ -1044,9 +1047,12 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             path, filename = os.path.split(tempProjectFile)
             args.append(filename)
             proc.setWorkingDirectory(os.path.join(self.project.ppath, path))
-            proc.finished.connect(self.__generateTSFileDone)
-            proc.readyReadStandardOutput.connect(self.__readStdoutLupdate)
-            proc.readyReadStandardError.connect(self.__readStderrLupdate)
+            proc.finished.connect(
+                lambda c, s: self.__generateTSFileDone(c, s, proc))
+            proc.readyReadStandardOutput.connect(
+                lambda: self.__readStdoutLupdate(proc))
+            proc.readyReadStandardError.connect(
+                lambda: self.__readStderrLupdate(proc))
             
             proc.start(self.pylupdate, args)
             procStarted = proc.waitForStarted()
@@ -1106,12 +1112,16 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     ##  Methods for the release commands
     ###########################################################################
     
-    def __releaseTSFileDone(self, exitCode, exitStatus):
+    def __releaseTSFileDone(self, exitCode, exitStatus, proc):
         """
         Private slot to handle the finished signal of the lrelease process.
         
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
+        @param proc reference to the process
+        @type QProcess
         """
         if exitStatus == QProcess.NormalExit and exitCode == 0:
             ui = e5App().getObject("UserInterface")
@@ -1144,7 +1154,6 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 self.tr(
                     "The release of the translation files (*.qm) has failed."))
         
-        proc = self.sender()
         for index in range(len(self.__lreleaseProcesses)):
             if proc == self.__lreleaseProcesses[index][0]:
                 try:
@@ -1196,7 +1205,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             lrelease = os.path.join(
                 Utilities.getQtBinariesPath(),
                 Utilities.generateQtToolName("lrelease"))
@@ -1214,9 +1223,12 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             path, filename = os.path.split(tempProjectFile)
             args.append(filename)
             proc.setWorkingDirectory(os.path.join(self.project.ppath, path))
-            proc.finished.connect(self.__releaseTSFileDone)
-            proc.readyReadStandardOutput.connect(self.__readStdoutLrelease)
-            proc.readyReadStandardError.connect(self.__readStderrLrelease)
+            proc.finished.connect(
+                lambda c, s: self.__releaseTSFileDone(c, s, proc))
+            proc.readyReadStandardOutput.connect(
+                lambda: self.__readStdoutLrelease(proc))
+            proc.readyReadStandardError.connect(
+                lambda: self.__readStderrLrelease(proc))
             
             proc.start(lrelease, args)
             procStarted = proc.waitForStarted()
