@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -60,14 +60,6 @@ class LexerContainer(Lexer, QsciLexer):
         """
         return ""
     
-    def styleBitsNeeded(self):
-        """
-        Public method to get the number of style bits needed by the lexer.
-        
-        @return number of style bits needed (integer)
-        """
-        return 5
-    
     def styleText(self, start, end):
         """
         Public method to perform the styling.
