@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,9 +9,9 @@ Module implementing a compatability interface class to QsciScintilla.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, Qt
-from PyQt5.QtGui import QPalette, QColor
-from PyQt5.QtWidgets import QApplication
+from PyQt5.QtCore import pyqtSignal, Qt, QPoint
+from PyQt5.QtGui import QPalette, QColor, QFontMetrics
+from PyQt5.QtWidgets import QApplication, QListWidget
 from PyQt5.Qsci import QsciScintillaBase, QsciScintilla, \
     QSCINTILLA_VERSION as QSCIQSCINTILLA_VERSION
 
@@ -75,6 +75,12 @@ class QsciScintillaCompat(QsciScintilla):
         
         self.userListActivated.connect(self.__completionListSelected)
         self.modificationChanged.connect(self.__modificationChanged)
+        
+        self.maxLines = 5
+        self.maxChars = 40
+        # Adjust the min. size of the autocomplete list box for short strings.
+        # Otherwise the width of the list box is at least the standard width.
+        self.SendScintilla(QsciScintilla.SCI_AUTOCSETMAXWIDTH, 5)
     
     def __modificationChanged(self, m):
         """
@@ -242,14 +248,6 @@ class QsciScintillaCompat(QsciScintilla):
         """
         self.SendScintilla(QsciScintilla.SCI_SETSTYLING, length, style)
     
-    def setStyleBits(self, bits):
-        """
-        Public method to set the number of bits to be used for styling.
-        
-        @param bits number of style bits (integer)
-        """
-        self.SendScintilla(QsciScintilla.SCI_SETSTYLEBITS, bits)
-    
     def charAt(self, pos):
         """
         Public method to get the character at a position in the text observing
@@ -752,6 +750,16 @@ class QsciScintillaCompat(QsciScintilla):
         except AttributeError:
             pass
     
+    def canPaste(self):
+        """
+        Public method to test, if the paste action is available (i.e. if the
+        clipboard contains some text).
+        
+        @return flag indicating the availability of 'paste'
+        @rtype bool
+        """
+        return self.SendScintilla(QsciScintilla.SCI_CANPASTE)
+    
     ###########################################################################
     ## methods to perform searches in target range
     ###########################################################################
@@ -1323,6 +1331,32 @@ class QsciScintillaCompat(QsciScintilla):
         self.SendScintilla(QsciScintilla.SCI_MARKERSETBACK,
                            QsciScintilla.SC_MARKNUM_FOLDEREND, backColor)
     
+    def getVisibleLineFromDocLine(self, docLine):
+        """
+        Public method to convert a document line number to a visible line
+        number (i.e. respect folded lines and annotations).
+        
+        @param docLine document line number to be converted
+        @type int
+        @return visible line number
+        @rtype int
+        """
+        return self.SendScintilla(QsciScintilla.SCI_VISIBLEFROMDOCLINE,
+                                  docLine)
+    
+    def getDocLineFromVisibleLine(self, displayLine):
+        """
+        Public method to convert a visible line number to a document line
+        number (i.e. respect folded lines and annotations).
+        
+        @param displayLine display line number to be converted
+        @type int
+        @return document line number
+        @rtype int
+        """
+        return self.SendScintilla(QsciScintilla.SCI_DOCLINEFROMVISIBLE,
+                                  displayLine)
+    
     ###########################################################################
     ## interface methods to the standard keyboard command set
     ###########################################################################
@@ -1374,7 +1408,7 @@ class QsciScintillaCompat(QsciScintilla):
         Public method to handle events.
         
         Note: We are not interested in the standard QsciScintilla event
-        handling because we do it our self.
+        handling because we do it ourselves.
         
         @param evt event object to handle (QEvent)
         @return result of the event handling (boolean)
@@ -1431,29 +1465,121 @@ class QsciScintillaCompat(QsciScintilla):
     ## replacements for buggy methods
     ###########################################################################
     
-    if "showUserList" not in QsciScintilla.__dict__:
-        def showUserList(self, id, lst):
-            """
-            Public method to show a user supplied list.
-            
-            @param id id of the list (integer)
-            @param lst list to be show (list of strings)
-            """
-            if id <= 0:
-                return
-            
-            self.SendScintilla(
-                QsciScintilla.SCI_AUTOCSETSEPARATOR,
-                ord(self.UserSeparator))
-            self.SendScintilla(
-                QsciScintilla.SCI_USERLISTSHOW, id,
-                self._encodeString(self.UserSeparator.join(lst)))
+    def showUserList(self, listId, lst):
+        """
+        Public method to show a user supplied list.
+        
+        @param listId id of the list (integer)
+        @param lst list to be show (list of strings)
+        """
+        if listId <= 0:
+            return
+        
+        # Setup seperator for user lists
+        self.SendScintilla(
+            QsciScintilla.SCI_AUTOCSETSEPARATOR, ord(self.UserSeparator))
+        self.SendScintilla(
+            QsciScintilla.SCI_USERLISTSHOW, listId,
+            self._encodeString(self.UserSeparator.join(lst)))
+        
+        self.updateUserListSize()
+    
+    def autoCompleteFromDocument(self):
+        """
+        Public method to resize list box after creation.
+        """
+        super(QsciScintillaCompat, self).autoCompleteFromDocument()
+        self.updateUserListSize()
+    
+    def autoCompleteFromAPIs(self):
+        """
+        Public method to resize list box after creation.
+        """
+        super(QsciScintillaCompat, self).autoCompleteFromAPIs()
+        self.updateUserListSize()
+    
+    def autoCompleteFromAll(self):
+        """
+        Public method to resize list box after creation.
+        """
+        super(QsciScintillaCompat, self).autoCompleteFromAll()
+        self.updateUserListSize()
     
     ###########################################################################
     ## work-arounds for buggy behavior
     ###########################################################################
     
-    def __completionListSelected(self, id, txt):
+    def updateUserListSize(self):
+        """
+        Public method to resize the completion list to fit with contents.
+        """
+        children = self.findChildren(QListWidget)
+        if children:
+            userListWidget = children[-1]
+            geom = userListWidget.geometry()
+            
+            baseHeight = geom.height()
+            
+            # Workaround for getting all items instead of
+            # userListWidget.items() call with unknown mime types.
+            all_items = userListWidget.findItems('', Qt.MatchStartsWith)
+            if not all_items:
+                return
+            
+            width = 0
+            maxItemHeight = 0
+            for item in all_items:
+                visualRect = userListWidget.visualItemRect(item)
+                itemWidth = visualRect.width()
+                if itemWidth > width:
+                    width = itemWidth
+                itemHeight = visualRect.height()
+                if itemHeight > maxItemHeight:
+                    maxItemHeight = itemHeight
+            
+            height = min(self.maxLines, len(all_items)) * maxItemHeight
+            # Just a fiddling factor: 2 for better readability,
+            # e.g. underscores at the end of the list.
+            height += 2
+            
+            # Borders
+            borders = geom.size() - userListWidget.contentsRect().size()
+            width += borders.width()
+            height += borders.height()
+            
+            font = userListWidget.font()
+            fm = QFontMetrics(font)
+            averageCharWidth = fm.averageCharWidth()
+            maxWidth = averageCharWidth * self.maxChars
+            if width > maxWidth:
+                width = maxWidth
+                height += userListWidget.horizontalScrollBar().sizeHint()\
+                    .height()
+                # List box doesn't honor limited size to show scroll bars, e.g.
+                # Python 2 on Win 10. So just force it.
+                userListWidget.setHorizontalScrollBarPolicy(
+                    Qt.ScrollBarAlwaysOn)
+            
+            if len(all_items) > self.maxLines:
+                width += userListWidget.verticalScrollBar().sizeHint().width()
+            
+            # Special case, where the space below current line where to less
+            yPos = geom.y()
+            charPos = self.SendScintilla(QsciScintilla.SCI_GETCURRENTPOS)
+            currentYPos = self.SendScintilla(
+                QsciScintilla.SCI_POINTYFROMPOSITION, 0, charPos)
+            
+            # X position doesn't matter: set to 0
+            globalPos = self.mapToGlobal(QPoint(0, currentYPos))
+            if yPos < globalPos.y():
+                deltaHeight = baseHeight - height
+                geom.setY(yPos + deltaHeight - 4)
+            
+            geom.setWidth(width)
+            geom.setHeight(height)
+            userListWidget.setGeometry(geom)
+    
+    def __completionListSelected(self, listId, txt):
         """
         Private slot to handle the selection from the completion list.
         
@@ -1462,7 +1588,7 @@ class QsciScintillaCompat(QsciScintilla):
         list but not giving it back when an item is selected via a
         double-click.
         
-        @param id the ID of the user list (integer)
+        @param listId the ID of the user list (integer)
         @param txt the selected text (string)
         """
         self.activateWindow()
@@ -1511,7 +1637,7 @@ class QsciScintillaCompat(QsciScintilla):
             pos = self.SendScintilla(QsciScintilla.SCI_POSITIONFROMLINE, line)
             
             # Allow for multi-byte characters
-            for i in range(index):
+            for _ in range(index):
                 pos = self.positionAfter(pos)
             
             return pos
