@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -253,7 +253,11 @@ class TaskViewer(QTreeWidget):
             self.__activating = True
             fn = itm.getFilename()
             if fn:
-                self.displayFile.emit(fn, itm.getLineno())
+                if os.path.exists(fn):
+                    self.displayFile.emit(fn, itm.getLineno())
+                else:
+                    if itm.isProjectTask():
+                        self.__deleteTask(itm)
             else:
                 self.__editTaskProperties()
             self.__activating = False
@@ -578,12 +582,18 @@ class TaskViewer(QTreeWidget):
                 self.__deleteSubTasks(subtask)
             self.tasks.remove(subtask)
     
-    def __deleteTask(self):
+    def __deleteTask(self, task=None):
         """
-        Private slot to handle the "Delete Task" context menu entry.
+        Private slot to delete a task.
+        
+        @param task task to be deleted
+        @type Task
         """
-        task = self.currentItem()
-        if self.copyTask == task:
+        if task is None:
+            # called via "Delete Task" context menu entry
+            task = self.currentItem()
+        
+        if self.copyTask is task:
             self.copyTask = None
         if task.childCount() > 0:
             self.__deleteSubTasks(task)
@@ -656,7 +666,7 @@ class TaskViewer(QTreeWidget):
         """
         Private slot to configure scan options for project tasks.
         """
-        filter, ok = QInputDialog.getText(
+        scanFilter, ok = QInputDialog.getText(
             self,
             self.tr("Scan Filter Patterns"),
             self.tr("Enter filename patterns of files"
@@ -664,7 +674,7 @@ class TaskViewer(QTreeWidget):
             QLineEdit.Normal,
             self.projectTasksScanFilter)
         if ok:
-            self.projectTasksScanFilter = filter
+            self.projectTasksScanFilter = scanFilter
     
     def regenerateProjectTasks(self, quiet=False):
         """
@@ -686,8 +696,9 @@ class TaskViewer(QTreeWidget):
         filterList = [f.strip() for f in self.projectTasksScanFilter.split(",")
                       if f.strip()]
         if filterList:
-            for filter in filterList:
-                files = [f for f in files if not fnmatch.fnmatch(f, filter)]
+            for scanFilter in filterList:
+                files = [f for f in files
+                         if not fnmatch.fnmatch(f, scanFilter)]
         
         # remove all project tasks
         self.clearProjectTasks(fileOnly=True)
