@@ -7,15 +7,19 @@
 from __future__ import unicode_literals
 
 from ctypes import (windll, Structure, byref, c_uint,
-                    create_unicode_buffer, sizeof, addressof)
+                    create_unicode_buffer, addressof)
 from ctypes.wintypes import HWND, UINT, LPCWSTR, BOOL
 import os.path as op
 
 from .compat import text_type
 
+kernel32 = windll.kernel32
+GetShortPathNameW = kernel32.GetShortPathNameW
+
 shell32 = windll.shell32
 SHFileOperationW = shell32.SHFileOperationW
 
+
 class SHFILEOPSTRUCTW(Structure):
     _fields_ = [
         ("hwnd", HWND),
@@ -28,6 +32,7 @@ class SHFILEOPSTRUCTW(Structure):
         ("lpszProgressTitle", LPCWSTR),
         ]
 
+
 FO_MOVE = 1
 FO_COPY = 2
 FO_DELETE = 3
@@ -39,11 +44,22 @@ FOF_NOCONFIRMATION = 16
 FOF_ALLOWUNDO = 64
 FOF_NOERRORUI = 1024
 
+
+def get_short_path_name(long_name):
+    if not long_name.startswith('\\\\?\\'):
+        long_name = '\\\\?\\' + long_name
+    buf_size = GetShortPathNameW(long_name, None, 0)
+    output = create_unicode_buffer(buf_size)
+    GetShortPathNameW(long_name, output, buf_size)
+    return output.value[4:]  # Remove '\\?\' for SHFileOperationW
+
+
 def send2trash(path):
     if not isinstance(path, text_type):
         path = text_type(path, 'mbcs')
     if not op.isabs(path):
         path = op.abspath(path)
+    path = get_short_path_name(path)
     fileop = SHFILEOPSTRUCTW()
     fileop.hwnd = 0
     fileop.wFunc = FO_DELETE
@@ -51,7 +67,7 @@ def send2trash(path):
     # Starting in python 3.6.3 it is no longer possible to use:
     # LPCWSTR(path + '\0') directly as embedded null characters are no longer
     # allowed in strings
-    # Workaround 
+    # Workaround
     #  - create buffer of c_wchar[] (LPCWSTR is based on this type)
     #  - buffer is two c_wchar characters longer (double null terminator)
     #  - cast the address of the buffer to a LPCWSTR
